@@ -18,7 +18,7 @@
   */
 function compatibility_version()
 {
-   return '2.0';
+   return '2.0.1';
 }
 
 
